OC.L10N.register(
    "settings",
    {
    "Private" : "Privato",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Visibile solo alle persone trovate con l'integrazione del numero di telefono via Talk su mobile",
    "Local" : "Locale",
    "Only visible to people on this instance and guests" : "Visibile solo alle persone in questa istanza e agli ospiti",
    "Federated" : "Federato",
    "Only synchronize to trusted servers" : "Sincronizzazione solo con i server affidabili",
    "Published" : "Pubblicato",
    "Synchronize to trusted servers and the global and public address book" : "Sincronizza con server affidabili e la rubrica globale e pubblica",
    "Verify" : "Verifica",
    "Verifying …" : "Verifica in corso...",
    "Unable to change password" : "Impossibile cambiare la password",
    "Very weak password" : "Password molto debole",
    "Weak password" : "Password debole",
    "So-so password" : "Password così-così",
    "Good password" : "Password buona",
    "Strong password" : "Password forte",
    "Groups" : "Gruppi",
    "Group list is empty" : "L'elenco dei gruppi è vuoto",
    "Unable to retrieve the group list" : "Impossibile recuperare l'elenco dei gruppi",
    "{actor} added you to group {group}" : "{actor} ti ha aggiunto al gruppo {group}",
    "You added {user} to group {group}" : "Hai aggiunto {user} al gruppo {group}",
    "{actor} added {user} to group {group}" : "{actor} ha aggiunto {user} al gruppo {group}",
    "An administrator added you to group {group}" : "Un amministratore ti ha aggiunto al gruppo {group}",
    "An administrator added {user} to group {group}" : "Un amministratore ha aggiunto {user} al gruppo {group}",
    "{actor} removed you from group {group}" : "{actor} ti ha rimosso dal gruppo {group}",
    "You removed {user} from group {group}" : "Hai rimosso {user} dal gruppo {group}",
    "{actor} removed {user} from group {group}" : "{actor} ha rimosso {user} dal gruppo {group}",
    "An administrator removed you from group {group}" : "Un amministratore ti ha rimosso dal gruppo {group}",
    "An administrator removed {user} from group {group}" : "Un amministratore ha rimosso {user} dal gruppo {group}",
    "Your <strong>group memberships</strong> were modified" : "Le tue <strong>appartenenze ai gruppi</strong> sono state modificate",
    "{actor} changed your password" : "{actor} ha cambiato la tua password",
    "You changed your password" : "Hai cambiato la tua password",
    "Your password was reset by an administrator" : "La tua password è stata reimpostata da un amministratore",
    "Your password was reset" : "La tua password è stata reimpostata",
    "{actor} changed your email address" : "{actor} ha cambiato il tuo indirizzo email",
    "You changed your email address" : "Hai cambiato il tuo indirizzo email",
    "Your email address was changed by an administrator" : "Il tuo indirizzo email è stato cambiato da un amministratore",
    "You created an app password for a session named \"{token}\"" : "Hai creato una password dell'applicazione per una sessione nominata \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Una amministratore ha creato una password dell'app per una sessione nominata \"{token}\"",
    "You deleted app password \"{token}\"" : "Hai eliminato la password di applicazione \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Hai rinominato la password dell'applicazione da \"{token}\" a \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Hai concesso l'accesso al filesystem alla password di applicazione \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Hai revocato l'accesso al filesystem dalla password di applicazione \"{token}\"",
    "Security" : "Sicurezza",
    "You successfully logged in using two-factor authentication (%1$s)" : "Hai effettuato correttamente l'accesso utilizzando l'autenticazione a due fattori (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Un tentativo di utilizzare l'autenticazione a due fattori non è riuscito (%1$s)",
    "Remote wipe was started on %1$s" : "Cancellazione remota avviata su %1$s",
    "Remote wipe has finished on %1$s" : "Cancellazione remota terminata su %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "La tua <strong>password</strong> o <strong>email</strong> è stata modificata",
    "Settings" : "Impostazioni",
    "Could not remove app." : "Impossibile rimuovere l'applicazione.",
    "Could not update app." : "Impossibile aggiornare l'applicazione.",
    "Wrong password" : "Password errata",
    "Unable to change personal password" : "Impossibile cambiare la password personale",
    "Saved" : "Salvato",
    "No Login supplied" : "Non è stato fornito alcun accesso",
    "Unable to change password. Password too long." : "Impossibile modificare la password. Password troppo lunga.",
    "Authentication error" : "Errore di autenticazione",
    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Fornisci una password amministrativa di ripristino; altrimenti, tutti i dati degli account saranno persi.",
    "Wrong admin recovery password. Please check the password and try again." : "Password amministrativa di ripristino errata. Controlla la password e prova ancora.",
    "Backend does not support password change, but the encryption of the account key was updated." : "Il backend non supporta la modifica della password, ma la cifratura della chiave dell'account è stata aggiornata.",
    "Administrator documentation" : "Documentazione amministratore",
    "User documentation" : "Documentazione utente",
    "Nextcloud help overview" : "Panoramica dell'aiuto per Nextcloud",
    "Invalid SMTP password." : "Password SMTP non valida.",
    "Email setting test" : "Prova impostazioni email",
    "Well done, %s!" : "Ben fatto, %s!",
    "If you received this email, the email configuration seems to be correct." : "Se hai ricevuto questo messaggio, la configurazione della posta elettronica dovrebbe essere corretta.",
    "Email could not be sent. Check your mail server log" : "Il messaggio non può essere inviato. Controlla il log del tuo server di posta",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Si è verificato un problema durante l'invio dell'email. Controlla le tue impostazioni. (Errore: %s)",
    "You need to set your account email before being able to send test emails. Go to %s for that." : "Devi impostare la tua email prima di poter inviare email di prova. Vai in %s per farlo.",
    "Recently active" : "Attivi di recente",
    "Disabled accounts" : "Account disabilitati",
    "Invalid account" : "Account non valido",
    "Invalid mail address" : "Indirizzo email non valido",
    "Settings saved" : "Impostazioni salvate",
    "Unable to change full name" : "Impossibile cambiare il nome completo",
    "Unable to change email address" : "Impossibile cambiare l'indirizzo di posta",
    "Unable to set invalid phone number" : "Impossibile impostare un numero di telefono non valido",
    "Unable to set invalid website" : "Impossibile impostare un sito web non valido",
    "Some account data was invalid" : "Alcuni dati dell'account non sono validi",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Per verificare il tuo account Twitter, pubblica il seguente tweet su Twitter (assicurati di pubblicarlo senza interruzioni di riga):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Per verificare il tuo sito web, memorizza il seguente contenuto nella radice del tuo sito in '.well-known/CloudIdVerificationCode.txt' (assicurati che l'intero testo sia in una riga):",
    "%1$s changed your password on %2$s." : "%1$s ha cambiato la tua password su %2$s.",
    "Your password on %s was changed." : "La tua password su %s è stata modificata.",
    "Your password on %s was reset by an administrator." : "La tua password su %s è stata reimpostata da un amministratore",
    "Your password on %s was reset." : "La tua password su %s è stata reimpostata.",
    "Password for %1$s changed on %2$s" : "Password per %1$s cambiata su %2$s",
    "Password changed for %s" : "Password modificata per %s",
    "If you did not request this, please contact an administrator." : "Se non lo hai richiesto, contatta un amministratore.",
    "Your email address on %s was changed." : "Il tuo indirizzo di posta su %s è stata modificato.",
    "Your email address on %s was changed by an administrator." : "Il tuo indirizzo di posta su %s è stato modificato da un amministratore.",
    "Email address for %1$s changed on %2$s" : "Indirizzo di posta per %1$s modificato su %2$s",
    "Email address changed for %s" : "Indirizzo di posta modificato per %s",
    "The new email address is %s" : "Il nuovo indirizzo email è %s",
    "Your %s account was created" : "Il tuo account %s è stato creato",
    "Welcome aboard" : "Benvenuto a bordo",
    "Welcome aboard %s" : "Benvenuto a bordo di %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Benvenuto nel tuo account %s, puoi aggiungere, proteggere e condividere i tuoi dati.",
    "Your Login is: %s" : "Il tuo accesso è: %s",
    "Set your password" : "Imposta la tua password",
    "Go to %s" : "Vai a %s",
    "Install Client" : "Installa client",
    "Apps" : "Applicazioni",
    "Personal" : "Personale",
    "Administration" : "Amministrazione",
    "Users" : "Utenti",
    "Additional settings" : "Impostazioni aggiuntive",
    "Assistant" : "Assistente",
    "Administration privileges" : "Privilegi di amministratore",
    "Groupware" : "Groupware",
    "Overview" : "Riepilogo",
    "Basic settings" : "Impostazioni di base",
    "Sharing" : "Condivisione",
    "Availability" : "Disponibilità",
    "Calendar" : "Calendario",
    "Personal info" : "Informazioni personali",
    "Mobile & desktop" : "Mobile e desktop",
    "Artificial Intelligence" : "Intelligenza artificiale",
    "Email server" : "Server di posta",
    "Mail Providers" : "Provider di Posta Elettronica",
    "Mail provider enables sending emails directly through the user's personal email account. At present, this functionality is limited to calendar invitations. It requires Nextcloud Mail 4.1 and an email account in Nextcloud Mail that matches the user's email address in Nextcloud." : "Il provider di posta elettronica consente l'invio di e-mail direttamente tramite l'account e-mail personale dell'utente. Al momento, questa funzionalità è limitata agli inviti del calendario. Richiede Nextcloud Mail 4.1 e un account e-mail in Nextcloud Mail che corrisponda all'indirizzo e-mail dell'utente in Nextcloud.",
    "Send emails using" : "Invia email usando",
    "User's email account" : "Account email degli utenti",
    "System email account" : "Account email di sistema",
    "Security & setup checks" : "Controlli di configurazione e sicurezza",
    "Background jobs" : "Operazioni in background",
    "Unlimited" : "Illimitata",
    "Verifying" : "Verifica",
    "Allowed admin IP ranges" : "Intervalli di IP consentiti",
    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "La chiave di configurazione \"%1$s\" si aspetta un array (%2$s trovato). La validazione dell'intervallo di IP amministrativi non verrà applicata.",
    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "La chiave di configurazione \"%1$s\" contiene intervalli di IP non validi: \"%2$s\"",
    "Admin IP filtering is correctly configured." : "Il filtro di IP amministrativi è configurato correttamente.",
    "App directories owner" : "Proprietario cartelle di app",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Alcune applicazioni sono di proprietà di un utente diverso da quello del server web. Questo potrebbe verificarsi se le applicazioni sono state installate manualmente. Controlla i permessi delle cartelle delle seguenti applicazioni:\n%s",
    "App directories have the correct owner \"%s\"" : "Le cartelle di app hanno il proprietario corretto \"%s\"",
    "Brute-force Throttle" : "Acceleratore Brute-force",
    "Your remote address could not be determined." : "Il tuo indirizzo remoto non può essere determinato.",
    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Il tuo indirizzo remoto è stato riconosciuto come \"%s\" e al momento l'accelleratore brute-force rallenta le performance di molte richieste. Se l'indirizzo remoto non è il tuo, questo può essere un'indicazione che un proxy non è configurato correttamente.",
    "Your remote address \"%s\" is not brute-force throttled." : "Il tuo indirizzo remoto \"%s\" non è accellerato in modalità brute-force.",
    "Old administration imported certificates" : "Certificati importati della vecchia amministrazione",
    "A background job is pending that checks for administration imported SSL certificates. Please check back later." : "È in sospeso un processo in background che controlla i certificati SSL importati dall'amministrazione. Controlla più tardi.",
    "There are some administration imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Sono presenti alcuni certificati SSL importati dall'amministrazione, che non vengono più utilizzati con Nextcloud 21. Possono essere importati dalla riga di comando tramite il comando \"occ security:certificates:import\". I loro percorsi all'interno della cartella dei dati sono mostrati di seguito.",
    "Code integrity" : "Integrità del codice",
    "Integrity checker has been disabled. Integrity cannot be verified." : "Il controllo di integrità è stato disattivato. L'integrità non può essere verificata.",
    "No altered files" : "Nessun file modificato",
    "Some files have not passed the integrity check. {link1} {link2}" : "Alcuni file non hanno superato il controllo di integrità. {link1} {link2}",
    "Cron errors" : "Errori di cron",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:\n%s" : "Non è stato possibile eseguire il job di cron tramite CLI. Sono apparsi i seguenti errori tecnici:\n%s",
    "The last cron job ran without errors." : "L'ultimo job di cron è stato eseguito senza errori.",
    "Cron last run" : "Ultimo avvio di Cron",
    "Last background job execution ran %s. Something seems wrong. {link}." : "L'ultima esecuzione del job in background è stata eseguita il %s. Potrebbe esserci un problema. {link}.",
    "Last background job execution ran %s." : "L'ultima esecuzione del job in cron è stata eseguita il %s.",
    "Data directory protected" : "Cartella dei dati protetta",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "La cartella dei dati e i tuoi file sono probabilmente accessibili da Internet. Il file .htaccess non funziona. Ti consigliamo vivamente di configurare il server in modo che la cartella dei dati non sia più accessibile o di spostare la cartella fuori dalla radice del server web.",
    "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "Non è stato possibile controllare se la cartella dei dati sia protetta. Controlla manualmente che il tuo server non permetta l'accesso alla cartella dei dati.",
    "Database missing columns" : "Colonne mancanti nel database",
    "Missing optional column \"%s\" in table \"%s\"." : "Manca la colonna facoltativa \"%s\" nella tabella \"%s\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Nel database mancano alcune colonne opzionali. Poiché l'aggiunta di colonne su tabelle grandi può richiedere del tempo, non sono state aggiunte automaticamente. Eseguendo \"occ db:add-missing-columns\", le colonne mancanti possono essere aggiunte manualmente mentre l'istanza è in esecuzione. Una volta che le colonne sono state aggiunte, alcune funzionalità potrebbero migliorare i tempi di risposta o l'usabilità.",
    "Database missing indices" : "Indici mancanti nel database",
    "Missing indices:" : "Indici mancanti:",
    "\"%s\" in table \"%s\"" : "\"%s\" nella tabella \"%s\"",
    "Database missing primary keys" : "Chiavi primarie mancanti nel database",
    "Missing primary key on table \"%s\"." : "Manca la chiave primaria sulla tabella \"%s\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Nel database mancano alcune chiavi primarie. Poiché l'aggiunta di chiavi primarie su tabelle grandi può richiedere del tempo, non sono state aggiunte automaticamente. Eseguendo \"occ db:add-missing-primary-keys\", quelle chiavi mancanti possono essere aggiunte manualmente mentre l'istanza è in esecuzione.",
    "Database pending bigint migrations" : "Database in attesa di migrazioni di bigint",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "In alcune colonne del database manca una conversione in big int. Poiché la modifica dei tipi di colonna su tabelle di grandi dimensioni potrebbe richiedere del tempo, non sono state modificate automaticamente. Eseguendo \"occ db:convert-filecache-bigint\" è possibile applicare manualmente le modifiche in sospeso. Questa operazione deve essere eseguita mentre l'istanza è offline.",
    "Debug mode" : "Modalità di debug",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Questa istanza sta funzionando in modalità debug. Attivala solo per lo sviluppo locale e non in ambienti di produzione.",
    "Debug mode is disabled." : "La modalità di debug è disabilitata.",
    "Default phone region" : "Regione telefonica predefinita",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "La tua installazione non ha una regione telefonica predefinita impostata. Ciò è necessario per poter convalidare i numeri di telefono nelle impostazioni del profilo senza un codice nazionale. Per consentire i numeri senza un codice nazionale, aggiungi \"default_phone_region\" con il rispettivo codice ISO 3166-1 della regione desiderata al file di configurazione.",
    "Email test" : "Prova email",
    "Email test was successfully sent" : "Il messaggio di prova è stato inviato correttamente",
    "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Non hai ancora impostato o verificato la configurazione del tuo server email. Vai alle \"Impostazioni di base\" per configurarle. Successivamente, utilizza il pulsante \"Invia email\" sotto il modulo per verificare le tue impostazioni.",
    "Transactional File Locking" : "Blocco transazionale dei file",
    "Transactional File Locking is disabled. This is not a a supported configuraton. It may lead to difficult to isolate problems including file corruption. Please remove the `'filelocking.enabled' => false` configuration entry from your `config.php` to avoid these problems." : "Il blocco transizionale dei file è disabilitato. Questa non è una configurazione supportata. Potrebbe risultare difficile isolare i problemi, inclusa la corruzione dei file. Per favore rimuovi la voce di configurazione `'filelocking.enabled' => false` dal tuo `config.php` per evitare questi problemi.",
    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "Il database viene usato per il blocco di file transazionale. Per migliorare le prestazioni, configura memcache, se disponibile.",
    "Forwarded for headers" : "Inoltrato per intestazioni",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "La tua impostazione \"trusted_proxies\" non è corretta, dovrebbe essere un array.",
    "Your \"trusted_proxies\" setting is not correctly set, it should be an array of IP addresses - optionally with range in CIDR notation." : "L'impostazione \"trusted_proxies\" non è impostata correttamente, dovrebbe essere un array di indirizzi IP, facoltativamente con intervallo nella notazione CIDR.",
    "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "La configurazione dell'intestazione del reverse proxy è errata. Questo è un problema di sicurezza e può consentire a un aggressore di falsificare il proprio indirizzo IP come visto da Nextcloud.",
    "Your IP address was resolved as %s" : "Il tuo indirizzo IP è stato risolto come %s",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "La configurazione dell'intestazione del reverse proxy è errata o stai accedendo a Nextcloud da un proxy fidato. Se non è così, si tratta di un problema di sicurezza e può consentire a un aggressore di falsificare il proprio indirizzo IP come visto da Nextcloud.",
    "HTTPS access and URLs" : "Accesso HTTPS e URL",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Accesso al sito non sicuro tramite HTTP. Ti consigliamo vivamente di configurare il tuo server per gestire le richieste HTTPS. Senza di esse alcune importanti funzionalità web come \"copia negli appunti\" o \"operatori di servizio\" non funzioneranno!",
    "Accessing site insecurely via HTTP." : "Accesso non sicuro al sito tramite HTTP.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "Stai accedendo alla tua istanza tramite una connessione protetta, tuttavia la tua istanza sta generando URL non sicuri. Ciò probabilmente significa che la tua istanza è protetta da un proxy inverso e che i valori di configurazione `overwrite*` di Nextcloud non sono impostati correttamente.",
    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "La tua istanza sta generando URL non sicuri. Se accedi alla tua istanza tramite HTTPS, probabilmente significa che la tua istanza si trova dietro un proxy inverso e che i valori di configurazione `overwrite*` di Nextcloud non sono impostati correttamente.",
    "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "Stai accedendo alla tua istanza tramite una connessione protetta e l'istanza sta generando URL protetti.",
    "Internet connectivity" : "Connessione internet",
    "Internet connectivity is disabled in configuration file." : "La connessione internet è disattivata nel file di configurazione.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Questo server non ha una connessione a Internet funzionante: diversi dispositivi finali non sono raggiungibili. Ciò significa che alcune delle funzionalità come il montaggio di archivi esterni, le notifiche degli aggiornamenti o l'installazione di applicazioni di terze parti non funzioneranno. Anche l'accesso remoto ai file e l'invio di email di notifica potrebbero non funzionare. Attiva la connessione a Internet del server se desideri disporre di tutte le funzionalità.",
    "JavaScript modules support" : "Supporto dei moduli JavaScript ",
    "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "Impossibile eseguire la verifica del supporto JavaScript. Rimedio o conferma manualmente se il tuo server web gestisce file `.mjs` utilizzando il tipo MIME JavaScript.",
    "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type." : "Il tuo server web non gestisce i file `.mjs` utilizzando il tipo MIME JavaScript. Ciò corromperà alcune app impedendo ai browser di eseguire i file JavaScript. Dovresti configurare il tuo server web per gestire i file `.mjs` con il tipo MIME `text/javascript` o `application/javascript`.",
    "JavaScript source map support" : "Supporto della mappa sorgente JavaScript",
    "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "Il tuo server web non è configurato per gestire i file `.js.map`. Senza questi file, le mappe sorgente JavaScript non funzioneranno correttamente, rendendo più difficile la risoluzione dei problemi e il debug di eventuali problemi che potrebbero verificarsi.",
    "Old server-side-encryption" : "Vecchia crittografia lato server",
    "Disabled" : "Disabilitata",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Il vecchio formato di cifratura lato server è abilitato. Ti consigliamo di disabilitarlo.",
    "Maintenance window start" : "Inizio della finestra di manutenzione",
    "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "Per il server non è configurata l'ora di inizio della finestra di manutenzione. Ciò significa che i lavori in background giornalieri ad uso intensivo di risorse verranno eseguiti anche durante l'orario di utilizzo principale. Ti consigliamo di impostarla su un orario di utilizzo ridotto, in modo che gli utenti siano meno interessati dal carico causato da questa attività pesante.",
    "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "La finestra di manutenzione per eseguire lavori pesanti in background inizia alle {start}:00 UTC e finisce alle {end}:00 UTC",
    "Memcache" : "Memcache",
    "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\"." : "Memcached è configurato come cache distribuita, ma è installato il modulo PHP sbagliato (\"memcache\"). Installa il modulo PHP \"memcached\".",
    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\"." : "Memcached è configurata come cache distribuita, ma il modulo PHP \"memcached\" non è installato. Installa il modulo PHP \"memcached\".",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Nessuna cache di memoria è stata configurata. Per migliorare le prestazioni, si prega di configurare una memcache, se disponibile.",
    "Failed to write and read a value from local cache." : "Impossibile scrivere e leggere un valore dalla cache locale.",
    "Failed to write and read a value from distributed cache." : "Impossibile scrivere e leggere un valore dalla cache distribuita.",
    "Configured" : "Configurato",
    "Mimetype migrations available" : "Migrazioni di tipi MIME disponibili",
    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "Sono disponibili una o più migrazioni di tipi MIME. Occasionalmente vengono aggiunti nuovi tipi MIME per gestire meglio determinati tipi di file. La migrazione dei tipi MIME richiede molto tempo su istanze più grandi, quindi questa operazione non viene eseguita automaticamente durante gli aggiornamenti. Utilizza il comando \"occ Maintenance:repair --include-expensive\" per eseguire le migrazioni.",
    "MySQL row format" : "Formato di riga MySQL",
    "You are not using MySQL" : "Non stai utilizzando MySQL",
    "None of your tables use ROW_FORMAT=Compressed" : "Nessuna delle tue tabelle utilizza ROW_FORMAT=Compressed",
    "Incorrect row format found in your database. ROW_FORMAT=Dynamic offers the best database performances for Nextcloud. Please update row format on the following list: %s." : "Formato di riga errato trovato nel database. ROW_FORMAT=Dynamic offre le migliori prestazioni del database per Nextcloud. Aggiorna il formato della riga nel seguente elenco: %s.",
    "MySQL Unicode support" : "Supporto Unicode MySQL",
    "MySQL is used as database and does support 4-byte characters" : "MySQL viene utilizzato come database e supporta caratteri a 4 byte",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "MySQL viene utilizzato come database ma non supporta caratteri a 4 byte. Per poter gestire caratteri a 4 byte (come gli emoji) senza problemi nei nomi dei file o nei commenti, ad esempio, si consiglia di abilitare il supporto a 4 byte in MySQL.",
    "OCS provider resolving" : "Risoluzione del provider OCS",
    "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "Impossibile verificare se il tuo server web risolve correttamente gli URL del provider OCM e OCS.",
    "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update." : "Il tuo server web non è configurato correttamente per risolvere %1$s.\nCiò è molto probabilmente correlato alla configurazione di un server Web che non è stata aggiornata per fornire direttamente questa cartella.\nConfronta la tua configurazione con le regole di riscrittura fornite in \".htaccess\" per Apache o con quella fornita nella documentazione per Nginx.\nSu Nginx queste sono in genere le righe che iniziano con \"location ~\" che necessitano di un aggiornamento.",
    "Overwrite CLI URL" : "Sovrascrivi URL CLI",
    "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "L'opzione \"overwrite.cli.url\" nel tuo config.php è impostata correttamente su \"%s\".",
    "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\"." : "L'opzione \"overwrite.cli.url\" nel tuo config.php è impostata su \"%s\" che è un URL corretto. L'URL suggerito è \"%s\".",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"%s\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Assicurati di impostare l'opzione \"overwrite.cli.url\" nel tuo file config.php sull'URL che i tuoi utenti utilizzano principalmente per accedere a questo Nextcloud. Suggerimento: \"%s\". Altrimenti potrebbero esserci problemi con la generazione dell'URL tramite cron. (È possibile tuttavia che l'URL suggerito non sia l'URL utilizzato principalmente dai tuoi utenti per accedere a Nextcloud. La cosa migliore in ogni caso è di ricontrollarlo.)\n ",
    "PHP APCu configuration" : "Configurazione PHP APCu",
    "Your APCu cache has been running full, consider increasing the apc.shm_size php setting." : "La tua cache APCu è piena, valuta la possibilità di aumentare l'impostazione php apc.shm_size.",
    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : "La tua cache APCu è quasi piena al %s%%, prendi in considerazione l'aumento dell'impostazione php apc.shm_size.",
    "PHP default charset" : "Set di caratteri PHP predefinito",
    "PHP configuration option \"default_charset\" should be UTF-8" : "L'opzione di configurazione PHP \"default_charset\" dovrebbe essere UTF-8",
    "PHP set_time_limit" : "PHP set_time_limit",
    "The function is available." : "La funzione è disponibile.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La funzione PHP \"set_time_limit\" non è disponibile. Ciò potrebbe comportare l'interruzione di script durante l'esecuzione, compromettendo la tua installazione. Ti consigliamo vivamente di abilitare questa funzione.",
    "Freetype" : "Freetype",
    "Supported" : "Supportata",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "La tua versione di PHP non supporta FreeType. Ciò causerà problemi con le immagini dei profili e con l'interfaccia delle impostazioni.",
    "PHP getenv" : "getenv PHP",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP non sembra essere configurato correttamente per interrogare le variabili d'ambiente di sistema. Il test con getenv(\"PATH\") restituisce solo una risposta vuota.",
    "PHP file size upload limit" : "Limite dimensione caricamento file PHP",
    "The PHP upload_max_filesize is too low. A size of at least %1$s is recommended. Current value: %2$s." : "Il valore PHP upload_max_filesize è troppo basso. Ti suggeriamo un valore di almeno %1$s. Valore attuale: %2$s.",
    "The PHP post_max_size is too low. A size of at least %1$s is recommended. Current value: %2$s." : "Il valore PHP post_max_size è troppo basso. Ti suggeriamo un valore di almeno %1$s. Valore attuale: %2$s.",
    "The PHP max_input_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "Il valore PHP max_input_time è troppo basso. Raccomandiamo un valore di almeno %1$s. Valore attuale: %2$s.",
    "The PHP max_execution_time is too low. A time of at least %1$s is recommended. Current value: %2$s." : "Il valore PHP max_execution_time è troppo basso. Raccomandiamo un valore di almeno %1$s. Valore attuale: %2$s.",
    "PHP memory limit" : "Limite di memoria PHP",
    "PHP modules" : "Moduli PHP",
    "This instance is missing some required PHP modules. It is required to install them: %s." : "Questa istanza manca di alcuni moduli PHP richiesti. È necessario installarli: %s.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "In questa istanza mancano alcuni moduli PHP consigliati. Ti consigliamo vivamente di installari per garantire prestazioni migliori e una migliore compatibilità:\n%s",
    "PHP opcache" : "PHP opcache",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Il modulo PHP OPcache non è caricato. Per prestazioni migliori consigliamo di caricarlo nella tua installazione di PHP.",
    "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "OPcache è disabilitata. Per prestazioni migliori, si consiglia di applicare \"opcache.enable=1\" alla configurazione PHP.",
    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply \"opcache.file_cache_only=0\" to your PHP configuration and use the file cache as second level cache only." : "L'OPcache basata sulla memoria condivisa è disabilitata. Per prestazioni migliori, si consiglia di applicare \"opcache.file_cache_only=0\" alla configurazione PHP e utilizzare la cache dei file esclusivamente come cache di secondo livello.",
    "OPcache is not working as it should, opcache_get_status() returns false, please check configuration." : "OPcache non funziona come dovrebbe, opcache_get_status() restituisce false, controlla la configurazione.",
    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply \"opcache.max_accelerated_files\" to your PHP configuration with a value higher than \"%s\"." : "Il numero massimo di chiavi OPcache è stato quasi superato. Per garantire che tutti gli script possano essere mantenuti nella cache, si consiglia di applicare \"opcache.max_accelerated_files\" alla configurazione PHP con un valore superiore a \"%s\".",
    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply \"opcache.memory_consumption\" to your PHP configuration with a value higher than \"%s\"." : "Il buffer OPcache è quasi pieno. Per garantire che tutti gli script possano essere conservati nella cache, si consiglia di applicare \"opcache.memory_consumption\" alla configurazione PHP con un valore superiore a \"%s\".",
    "The PHP OPcache module is not properly configured. %s." : "Il modulo PHP OPcache non è correttamente configurato. %s.",
    "Correctly configured" : "Configurato correttamente",
    "PHP version" : "Versione PHP",
    "You are currently running PHP %s." : "Attualmente stai usando PHP %s.",
    "PHP \"output_buffering\" option" : "Opzione di PHP \"output_buffering\"",
    "PHP configuration option \"output_buffering\" must be disabled" : "La configurazione di PHP \"output_buffering\" deve essere disattivata",
    "Random generator" : "Generatore casuale",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons." : "Nessuna fonte adatta per la casualità è stata trovata da PHP, il quale è fortemente sconsigliato per motivi di sicurezza.",
    "Secure" : "Sicuro",
    "Configuration file access rights" : "Diritti di accesso al file di configurazione",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configurazione di sola lettura è stata abilitata. Ciò impedisce l'impostazione di alcune configurazioni tramite l'interfaccia web. Inoltre, i file devono essere resi scrivibili manualmente per ogni aggiornamento.",
    "Nextcloud configuration file is writable" : "Il file di configurazione di Nextcloud è scrivibile",
    "HTTP headers" : "Intestazioni HTTP",
    "Database version" : "Versione del database",
    "Unknown database platform" : "Piattaforma di database sconosciuta",
    "Architecture" : "Architettura",
    "64-bit" : "64-bit",
    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit!" : "Sembra che tu stia usando una versione di PHP a 32-bit. Nextcloud richiede 64-bit per funzionare. Aggiorna il tuo sistema operativo e PHP a 64-bit!",
    "Database transaction isolation level" : "Livello di isolamento delle transazioni del database",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Il tuo database non è in esecuzione con il livello di isolamento delle transazioni \"READ COMMITTED\". Ciò può causare problemi quando diverse azioni sono eseguite in parallelo.",
    "Was not able to get transaction isolation level: %s" : "Impossibile ottenere il livello di isolamento della transazione: %s",
    "Profile information" : "Informazioni del profilo",
    "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Immagine del profilo, nome e cognome, email, numero di telefono, indirizzo, sito web, Twitter, organizzazione, ruolo, titolo, biografia e se il tuo profilo è attivo o meno",
    "Nextcloud settings" : "Impostazioni di Nextcloud",
    "Enable" : "Abilita",
    "Machine translation" : "Traduzione automatica",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "La traduzione automatica può essere implementata da diverse applicazioni. Qui puoi definire la priorità delle applicazioni di traduzione automatica che sono installate al momento.",
    "Image generation" : "Generazione di immagini",
    "Image generation can be implemented by different apps. Here you can set which app should be used." : "La generazione di immagini può essere implementata da diverse applicazioni. Qui puoi impostare quale applicazioni dovrebbe essere utilizzata.",
    "None of your currently installed apps provide image generation functionality" : "Nessuna delle tue applicazioni attualmente installate fornisce funzionalità di generazione di immagini",
    "Text processing" : "Elaborazione del testo",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "L'elaborazione del testo può essere implementata da diverse applicazioni. Qui puoi impostare quale applicazioni usare per quale compito.",
    "Task:" : "Compito:",
    "Here you can decide which group can access certain sections of the administration settings." : "Qui puoi decidere quali gruppi possono accedere ad alcune sezioni delle impostazioni di amministrazione.",
    "Unable to modify setting" : "Impossibile modificare l'impostazione",
    "None" : "Nessuno",
    "Changed disclaimer text" : "Cambia testo della clausola",
    "Deleted disclaimer text" : "Eliminato testo della clausola",
    "Could not set disclaimer text" : "Impossibile impostare il testo della clausola",
    "Allow apps to use the Share API" : "Consenti alle applicazioni di utilizzare le API di condivisione",
    "Allow resharing" : "Consenti la ri-condivisione",
    "Allow sharing with groups" : "Consenti la condivisione con gruppi",
    "Restrict users to only share with users in their groups" : "Limita gli utenti a condividere solo con gli utenti nei loro gruppi",
    "Allow users to share via link and emails" : "Consenti agli utenti di condividere tramite collegamento e email",
    "Allow public uploads" : "Consenti caricamenti pubblici",
    "Always ask for a password" : "Chiedi sempre una password",
    "Enforce password protection" : "Imponi la protezione con password",
    "Exclude groups from password requirements" : "Escludi gruppi dai requisiti della password",
    "Exclude groups from creating link shares" : "Escludi gruppi dalla creazione dei collegamenti di condivisione",
    "Allow users to set custom share link tokens" : "Consenti agli utenti di impostare token di collegamento personalizzati",
    "Shares with custom tokens will continue to be accessible after this setting has been disabled" : "Le condivisioni con token personalizzati continueranno a essere accessibili dopo aver disabilitato questa impostazione",
    "Shares with guessable tokens may be accessed easily" : "Le condivisioni con token indovinabili sono facilmente accessibili",
    "Limit sharing based on groups" : "Limita la condivisione in base ai gruppi",
    "Exclude some groups from sharing" : "Escludi alcuni gruppi dalla condivisione",
    "Limit sharing to some groups" : "Limita la condivisione ad alcuni gruppi",
    "Groups allowed to share" : "Gruppi autorizzati a condividere",
    "Groups excluded from sharing" : "Gruppi esclusi dalla condivisione",
    "Not allowed groups will still be able to receive shares, but not to initiate them." : "I gruppi non autorizzati potranno comunque ricevere condivisioni, ma non avviarle.",
    "Set default expiration date for internal shares" : "Imposta la data di scadenza predefinita per le condivisioni interne",
    "Enforce expiration date" : "Forza la data di scadenza",
    "Default expiration time of new shares in days" : "Scadenza predefinita delle nuove condivisioni in giorni",
    "Expire shares after x days" : "Scadenza delle condivisioni dopo x giorni",
    "Set default expiration date for shares to other servers" : "Imposta la data di scadenza predefinita per le condivisioni ad altri server",
    "Enforce expiration date for remote shares" : "Imponi la data di scadenza per le condivisioni remote",
    "Default expiration time of remote shares in days" : "Tempo di scadenza predefinito delle condivisioni remote in giorni",
    "Expire remote shares after x days" : "Scadenza delle condivisioni remote dopo x giorni",
    "Set default expiration date for shares via link or mail" : "Imposta la data di scadenza predefinita per le condivisioni tramite link o posta",
    "Default expiration time of shares in days" : "Scadenza predefinita delle condivisioni in giorni",
    "Privacy settings for sharing" : "Impostazioni sulla privacy per la condivisione",
    "Allow account name autocompletion in share dialog and allow access to the system address book" : "Consenti il ​​completamento automatico del nome dell'account nella finestra di dialogo di condivisione e consenti l'accesso alla rubrica di sistema",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Mostra il testo della liberatoria sulla pagina di caricamento del collegamento pubblico (visualizzato solo quando l'elenco dei file è nascosto)",
    "Disclaimer text" : "Testo della clausola",
    "This text will be shown on the public link upload page when the file list is hidden." : "Questo testo sarà mostrato sulla pagina di caricamento del collegamento pubblico quando l'elenco dei file è nascosto.",
    "Default share permissions" : "Permessi predefiniti di condivisione",
    "Two-Factor Authentication" : "Autenticazione a due fattori",
    "Enforce two-factor authentication" : "Applica l'autenticazione a due fattori",
    "Limit to groups" : "Limita a gruppi",
    "Enforcement of two-factor authentication can be set for certain groups only." : "L'applicazione dell'autenticazione a due fattori può essere impostata solo per determinati gruppi.",
    "Two-factor authentication is enforced for all members of the following groups." : "L'autenticazione a due fattori è applicata per tutti membri dei gruppi seguenti.",
    "Enforced groups" : "Gruppi imposti",
    "Two-factor authentication is not enforced for members of the following groups." : "L'autenticazione a due fattori non è applicata per i membri dei gruppi seguenti.",
    "Excluded groups" : "Gruppi esclusi",
    "Save changes" : "Salva le modifiche",
    "Default" : "Predefinito",
    "Show details for {appName} app" : "Mostra dettagli per l'applicazione {appName}",
    "Update to {update}" : "Aggiorna a {update}",
    "Remove" : "Rimuovi",
    "Featured" : "In evidenza",
    "This app is supported via your current Nextcloud subscription." : "Questa applicazione è supportata tramite la tua sottoscrizione attuale di Nextcloud.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Le applicazioni in evidenza sono sviluppate dalla comunità. Esse offrono nuove funzionalità e sono pronte per l'uso in produzione.",
    "Disable all" : "Disabilita tutto",
    "Download and enable all" : "Scarica e abilita tutti",
    "All apps are up-to-date." : "Tutte le applicazioni sono aggiornate.",
    "Icon" : "Icona",
    "Name" : "Nome",
    "Version" : "Versione",
    "Level" : "Livello",
    "Actions" : "Azioni",
    "Results from other categories" : "Risultati da altre categorie",
    "No apps found for your version" : "Nessuna applicazione trovata per la tua versione",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n applicazione ha un aggiornamento disponibile","%n applicazioni hanno un aggiornamento disponibile","%n applicazioni hanno un aggiornamento disponibile"],
    "_Update_::_Update all_" : ["Aggiorna","Aggiorna","Aggiorna tutto"],
    "Failed to load groups" : "Impossibile caricare i gruppi",
    "Failed to create group" : "Creazione gruppo fallita",
    "Create group" : "Crea gruppo",
    "Group name" : "Nome del gruppo",
    "Please enter a valid group name" : "Inserisci un nome di gruppo valido",
    "Loading groups…" : "Caricamento gruppi...",
    "Nothing to show" : "Niente da mostrare",
    "Loading" : "Caricamento",
    "Carousel" : "Carosello",
    "Daemon" : "Demone",
    "Type" : "Tipo",
    "Display Name" : "Nome visualizzato",
    "Learn more" : "Scopri altro",
    "Confirm" : "Conferma",
    "Cancel" : "Annulla",
    "Description" : "Descrizione",
    "View in store" : "Visualizza nel negozio",
    "Visit website" : "Visita il sito web",
    "Usage documentation" : "Manuale d'uso",
    "Admin documentation" : "Documentazione di amministrazione",
    "Developer documentation" : "Documentazione dello sviluppatore",
    "Details" : "Dettagli",
    "All" : "Tutti",
    "Limit app usage to groups" : "Limita l'utilizzo dell'applicazione a gruppi",
    "No results" : "Nessun risultato",
    "Update to {version}" : "Aggiorna a {version}",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Questa applicazione non può essere installata perché le seguenti dipendenze non sono soddisfatte:",
    "Author" : "Autore",
    "Categories" : "Categorie",
    "Resources" : "Risorse",
    "Documentation" : "Documentazione",
    "Interact" : "Interagisci",
    "Report a bug" : "Segnala un bug",
    "Request feature" : "Richiedi funzionalità",
    "Ask questions or discuss" : "Domanda o discuti",
    "Rate the app" : "Valuta l'applicazione",
    "Rate" : "Valuta",
    "Changelog" : "Novità",
    "Google Chrome for Android" : "Google Chrome per Android",
    "{productName} iOS app" : "Applicazione iOS di {productName}",
    "{productName} Android app" : "Applicazione Android di {productName}",
    "{productName} Talk for iOS" : "{productName} Talk per iOS",
    "{productName} Talk for Android" : "{productName} Talk per Android",
    "Sync client" : "Client di sincronizzazione",
    "This session" : "Questa sessione",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Device name" : "Nome dispositivo",
    "Cancel renaming" : "Annulla la rinomina",
    "Save new name" : "Salva nuovo nome",
    "Marked for remote wipe" : "Marcato come cancellazione remota",
    "Device settings" : "Impostazioni dei dispositivi",
    "Allow filesystem access" : "Consenti accesso al filesystem",
    "Rename" : "Rinomina",
    "Revoke" : "Revoca",
    "Wipe device" : "Cancella dispositivo",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "La revoca di questo token potrebbe impedire la cancellazione del tuo dispositivo se non ha ancora iniziato la cancellazione.",
    "Device" : "Dispositivo",
    "Last activity" : "Ultima attività",
    "Devices & sessions" : "Dispositivi e sessioni",
    "Web, desktop and mobile clients currently logged in to your account." : "Client web, desktop e mobile attualmente connessi al tuo account.",
    "Error while creating device token" : "Errore durante la creazione del token",
    "App name" : "Nome applicazione",
    "Create new app password" : "Crea nuova password di applicazione",
    "App password copied!" : "Password dell'applicazione copiata!",
    "Copy app password" : "Copia password dell'applicazione",
    "Login name copied!" : "Nome di accesso copiato!",
    "Copy login name" : "Copia nome di accesso",
    "Could not copy app password. Please copy it manually." : "Impossibile copiare la password dell'applicazione. Copiala a mano.",
    "New app password" : "Nuova password dell'applicazione",
    "Login" : "Login",
    "Password" : "Password",
    "Show QR code for mobile apps" : "Mostra il codice QR per le applicazioni mobili",
    "Use system cron service to call the cron.php file every 5 minutes." : "Usa il servizio cron di sistema per invocare il file cron.php ogni 5 minuti.",
    "The cron.php needs to be executed by the system account \"{user}\"." : "Il cron.php deve essere eseguito dall'account di sistema \"{user}\".",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "È necessaria l'estensione POSIX di PHP. Vedi la {linkstart}documentazione di PHP{linkend} per maggiori dettagli.",
    "Unable to update background job mode" : "Impossibile aggiornare la modalità delle operazioni in background",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Per un buon funzionamento del server, è importante configurare le operazioni in background correttamente. \"Cron\" è l'impostazione consigliata. Vedi la documentazione per ulteriori informazioni.",
    "Last job execution ran {time}. Something seems wrong." : "Ultima esecuzione di cron: {time}. Potrebbe esserci un problema.",
    "Last job ran {relativeTime}." : "Ultima esecuzione: {relativeTime}.",
    "Background job did not run yet!" : "Operazione in background non ancora eseguita!",
    "AJAX" : "AJAX",
    "Webcron" : "Webcron",
    "Cron (Recommended)" : "Cron (Consigliato)",
    "Unable to update profile default setting" : "Impossibile aggiornare l'impostazione predefinita del profilo",
    "Profile" : "Profilo",
    "Password confirmation is required" : "La conferma della password è richiesta",
    "Unable to update server side encryption config" : "Impossibile aggiornare la configurazione della crittografia lato server",
    "Server-side encryption" : "Cifratura lato server",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La cifratura lato server rende possibile cifrare i file caricati sul server. Ciò presenta dei limiti, come una riduzione delle prestazioni, perciò abilita questa funzione solo se necessario.",
    "Enable server-side encryption" : "Abilita cifratura lato server",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nessun modulo di cifratura caricato, carica un modulo di cifratura nel menu delle applicazioni.",
    "Select default encryption module:" : "Seleziona il modulo di cifratura predefinito:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Devi migrare le tue chiavi di cifratura dalla vecchia crittografia (ownCloud <= 8.0) alla nuova. Attiva il \"Modulo di cifratura predefinito\" ed esegui {command}",
    "Enable encryption" : "Abilita cifratura",
    "Please read carefully before activating server-side encryption:" : "Leggi attentamente prima di attivare la cifratura lato server:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Quando la cifratura è abilitata, tutti i file caricati sul server da quel momento in poi saranno cifrati sul server. Sarà possibile solo disabilitare successivamente la cifratura se il modulo di cifratura attivo lo consente, e se tutti i prerequisiti (ad es. l'impostazione di una chiave di recupero) sono verificati.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "La sola cifratura non garantisce la sicurezza del sistema. Leggi la documentazione per ottenere ulteriori informazioni sul funzionamento dell'applicazione di cifratura.",
    "Be aware that encryption always increases the file size." : "Considera che la cifratura incrementa sempre la dimensione dei file.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Ti consigliamo di creare copie di sicurezza dei tuoi dati con regolarità, in caso di utilizzo della cifratura, assicurati di creare una copia delle chiavi di cifratura insieme ai tuoi dati.",
    "This is the final warning: Do you really want to enable encryption?" : "Questo è l'ultimo avviso: vuoi davvero abilitare la cifratura?",
    "Please confirm the group removal" : "Conferma la rimozione del gruppo",
    "Submit" : "Invia",
    "Rename group" : "Rinomina gruppo",
    "Current password" : "Password attuale",
    "New password" : "Nuova password",
    "Change password" : "Modifica password",
    "Choose your profile picture" : "Scegli la tua immagine del profilo",
    "Please select a valid png or jpg file" : "Scegli un file png o jpg valido",
    "Error setting profile picture" : "Errore durante l'impostazione dell'immagine del profilo",
    "Error cropping profile picture" : "Errore durante il ritaglio dell'immagine del profilo",
    "Error saving profile picture" : "Errore durante il salvataggio dell'immagine del profilo",
    "Error removing profile picture" : "Errore durante la rimozione dell'immagine del profilo",
    "Your profile picture" : "La tua immagine del profilo",
    "Upload profile picture" : "Carica immagine del profilo",
    "Choose profile picture from Files" : "Scegli immagine del profilo da File",
    "Remove profile picture" : "Rimuovi immagine del profilo",
    "The file must be a PNG or JPG" : "Il file deve essere una PNG o JPG",
    "Picture provided by original account" : "Immagine fornita dall'account originale",
    "Set as profile picture" : "Imposta come immagine del profilo",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Tieni presente che possono essere necessarie fino a 24 ore prima che l'immagine del profilo venga aggiornata dappertutto.",
    "You are a member of the following groups:" : "Sei un membro dei seguenti gruppi:",
    "Your full name" : "Il tuo nome completo",
    "Email options" : "Opzioni email",
    "Remove primary email" : "Rimuovi email principale",
    "Delete email" : "Elimina email",
    "This address is not confirmed" : "Questo indirizzo non è confermato",
    "Unset as primary email" : "Togli dall'email principale",
    "Set as primary email" : "Imposta come email principale",
    "Additional email address {index}" : "Indirizzo email aggiuntivo {index}",
    "Unable to delete primary email address" : "Impossibile eliminare l'indirizzo di posta principale",
    "Unable to update primary email address" : "Impossibile aggiornare l'indirizzo di posta principale",
    "Unable to add additional email address" : "Impossibile aggiungere l'indirizzo di posta aggiuntivo",
    "Unable to update additional email address" : "Impossibile aggiornare l'indirizzo di posta aggiuntivo",
    "Unable to delete additional email address" : "Impossibile eliminare l'indirizzo di posta aggiuntivo",
    "Primary email for password reset and notifications" : "Email principale per ripristino della password e notifiche",
    "No email address set" : "Nessun indirizzo email impostato",
    "Your handle" : "Il tuo collegamento",
    "Your headline" : "Il tuo titolo",
    "Unable to update language" : "Impossibile aggiornare la lingua",
    "Languages" : "Lingue",
    "Help translate" : "Migliora la traduzione",
    "No language set" : "Nessuna lingua impostata",
    "Unable to update locale" : "Impossibile aggiornare la lingua",
    "Week starts on {firstDayOfWeek}" : "La settimana inizia: {firstDayOfWeek}",
    "No locale set" : "Nessuna lingua impostata",
    "Your city" : "La tua città",
    "Your organisation" : "La tua organizzazione",
    "Edit your Profile visibility" : "Modifica la visibilità del profilo",
    "Unable to update profile enabled state" : "Impossibile aggiornare lo stato di attivazione del profilo",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "L'impostazione più restrittiva di visibilità o ambito è rispettata sul tuo profilo. Ad esempio, quando la visibilità è su \"Mostra a tutti\" e l'ambito è su \"Privato\", verrà rispettato \"Privato\".",
    "Unable to update visibility of {displayId}" : "Impossibile aggiornare la visibilità di {displayId}",
    "Your role" : "Il tuo ruolo",
    "Timezone" : "Fuso orario",
    "Your X (formerly Twitter) handle" : "Il tuo handle di X (ex Twitter)",
    "Your website" : "Il tuo sito web",
    "Invalid value" : "Valore non valido",
    "Unable to update {property}" : "Impossibile aggiornare {property}",
    "No {property} set" : "Nessun {property} impostato",
    "Change scope level of {property}, current scope is {scope}" : "Cambia libello di ambito di {property}, l'attuale ambito è {scope}",
    "Unable to update federation scope of the primary {property}" : "Impossibile aggiornare l'ambito federativo del {property} primario",
    "Unable to update federation scope of additional {property}" : "Impossibile aggiornare l'ambito federativo del {property} aggiuntivo",
    "Add additional email" : "Aggiungi email aggiuntiva",
    "Add" : "Aggiungi",
    "Create" : "Crea",
    "Change" : "Modifica",
    "Delete" : "Elimina",
    "Reshare" : "Ri-condividi",
    "School" : "Scuola",
    "Default language" : "Lingua predefinita",
    "Common languages" : "Lingue comuni",
    "Other languages" : "Altre lingue",
    "Password change is disabled because the master key is disabled" : "La modifica della password è disabilitata poiché la chiave principale è disabilitata",
    "Loading accounts …" : "Caricamento account in corso...",
    "Manager" : "Responsabile",
    "Failed to search groups" : "Impossibile cercare i gruppi",
    "New account" : "Nuovo account",
    "Display name" : "Nome visualizzato",
    "Either password or email is required" : "La password o l'email è necessaria",
    "Password (required)" : "Password (richiesta)",
    "Email (required)" : "Email (richiesta)",
    "Email" : "Posta elettronica",
    "Member of the following groups" : "Membro dei seguenti gruppi",
    "Quota" : "Quote",
    "Language" : "Lingua",
    "Set default language" : "Imposta lingua predefinita",
    "Total rows summary" : "Riepilogo totale delle righe",
    "Scroll to load more rows" : "Scorri per caricare più righe",
    "Password or insufficient permissions message" : "Messaggio password o permessi insufficienti",
    "Avatar" : "Avatar",
    "Account name" : "Nome account",
    "Group admin for" : "Amministratore per il gruppo",
    "Storage location" : "Posizione di archiviazione",
    "Last login" : "Ultimo accesso",
    "Account actions" : "Azioni account",
    "{size} used" : "{size} utilizzati",
    "Delete account" : "Elimina account",
    "Disable account" : "Disabilita account",
    "Enable account" : "Abilita account",
    "Resend welcome email" : "Invia nuovamente email di benvenuto",
    "Remote wipe of devices" : "Cancellazione remota dei dispositivi",
    "Wipe {userid}'s devices" : "Cancella i dispositivi di {userid}",
    "Wiped {userid}'s devices" : "Dispositivi di {userid} cancellati",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Elimina completamente l'account {userid} inclusi tutti i file personali, i dati delle applicazioni, ecc.",
    "Account deletion" : "Eliminazione account",
    "Delete {userid}'s account" : "Elimina l'account di {userid}",
    "Display name was successfully changed" : "Nome visualizzato modificato correttamente",
    "Password was successfully changed" : "Password modificata correttamente",
    "Email was successfully changed" : "Email modificata correttamente",
    "Welcome mail sent!" : "Email di benvenuto inviata!",
    "Change display name" : "Cambia nome visualizzato",
    "Set new password" : "Imposta una nuova password",
    "Set new email address" : "Imposta un nuovo indirizzo email",
    "Set the language" : "Imposta la lingua",
    "Done" : "Completato",
    "Edit" : "Modifica",
    "Visibility" : "Visibilità",
    "Show language" : "Mostra lingua",
    "Show storage path" : "Mostra percorso di archiviazione",
    "Show last login" : "Mostra ultimo accesso",
    "Sorting" : "Ordina",
    "By member count" : "Per numero di partecipanti",
    "By name" : "Per nome",
    "Send email" : "Invia email",
    "Send welcome email to new accounts" : "Invia email di benvenuto ai nuovi utenti",
    "Defaults" : "Predefiniti",
    "Default quota" : "Quota predefinita",
    "Select default quota" : "Seleziona la quota predefinita",
    "Server error while trying to complete WebAuthn device registration" : "Errore del server durante il tentativo di completare la registrazione del dispositivo WebAuthn",
    "Passwordless authentication requires a secure connection." : "L'autenticazione senza password richiede una connessione sicura.",
    "Add WebAuthn device" : "Aggiungi dispositivo WebAuthn",
    "Please authorize your WebAuthn device." : "Autorizza il tuo dispositivo WebAuthn.",
    "Adding your device …" : "Aggiunta del tuo dispositivo …",
    "Unnamed device" : "Dispositivo senza nome",
    "Passwordless Authentication" : "Autenticazione senza password",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Configura il tuo account per l'autenticazione senza password seguendo lo standard FIDO2.",
    "No devices configured." : "Nessun dispositivo configurato.",
    "The following devices are configured for your account:" : "I seguenti dispositivi sono configurati per il tuo account:",
    "Your browser does not support WebAuthn." : "Il tuo browser non supporta WebAuthn.",
    "Security & setup warnings" : "Avvisi di sicurezza e di configurazione",
    "Try again" : "Riprova",
    "All checks passed." : "Tutti i controlli passati.",
    "There are some errors regarding your setup." : "Sono presenti degli errori relativi alla tua configurazione.",
    "There are some warnings regarding your setup." : "Sono presenti degli avvisi relativi alla tua configurazione.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "In qualità di amministratore puoi configurare in modo granulare il comportamento della condivisione. Vedi la documentazione per ulteriori informazioni.",
    "You need to enable the File sharing App." : "Devi attivare l'applicazione Condivisione file.",
    "App Store" : "App Store",
    "Apply" : "Applica",
    "Admins" : "Amministratori",
    "Sending…" : "Invio in corso...",
    "Email sent" : "Email inviata",
    "Location" : "Posizione",
    "Profile picture" : "Immagine del profilo",
    "About" : "Informazioni",
    "Full name" : "Nome completo",
    "Additional email" : "Email aggiuntiva",
    "Fediverse (e.g. Mastodon)" : "Fediverso (es. Mastodon)",
    "Headline" : "Titolo",
    "Organisation" : "Organizzazione",
    "Phone number" : "Numero di telefono",
    "Pronouns" : "Pronomi",
    "Role" : "Ruolo",
    "X (formerly Twitter)" : "X (ex Twitter)",
    "Website" : "Sito web",
    "Profile visibility" : "Visibilità del profilo",
    "Locale" : "Localizzazione",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Non disponibile poiché questa proprietà è necessaria per funzioni di base inclusi la condivisione di file e gli inviti via calendario.",
    "Your apps" : "Le tue applicazioni",
    "Active apps" : "Applicazioni attive",
    "Disabled apps" : "Applicazioni disabilitate",
    "Updates" : "Aggiornamenti",
    "App bundles" : "Pacchetti di applicazioni",
    "Featured apps" : "Applicazioni in evidenza",
    "Supported apps" : "Applicazioni supportate",
    "Show to everyone" : "Mostra a tutti",
    "Show to logged in accounts only" : "Mostra solo agli account che hanno effettuato l'accesso",
    "Hide" : "Nascondi",
    "Download and enable" : "Scarica e abilita",
    "Disable" : "Disabilita",
    "Allow untested app" : "Consenti applicazione non verificata",
    "The app will be downloaded from the App Store" : "L'applicazione sarà scaricata dal negozio delle applicazioni",
    "Unknown" : "Sconosciuto",
    "Never" : "Mai",
    "An error occurred during the request. Unable to proceed." : "Si è verificato un errore durante la richiesta. Impossibile continuare.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Errore: questa applicazione non può essere abilitata perché rende il server instabile",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'applicazione è stata abilitata, ma deve essere aggiornata. Sarai rediretto alla pagina di aggiornamento in 5 secondi.",
    "Do you really want to wipe your data from this device?" : "Vuoi davvero eliminare tutti i dati da questo dispositivo?",
    "Confirm wipe" : "Conferma eliminazione",
    "Could not delete the app token" : "Impossibile eliminare il token dell'applicazione",
    "Error while wiping the device with the token" : "Errore durante la cancellazione del dispositivo con il token",
    "Error while updating device token name" : "Errore durante l'aggiornamento del nome del token del dispositivo",
    "Error while updating device token scope" : "Errore durante l'aggiornamento del campo del token del dispositivo",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Sono arrivate troppe richieste dalla tua rete. Riprova più tardi o contatta il tuo amministratore se questo è un errore.",
    "Error" : "Errore",
    "Account documentation" : "Documentazione dell'account",
    "Administration documentation" : "Documentazione di amministrazione",
    "Forum" : "Forum",
    "General documentation" : "Documentazione generale",
    "Legal notice" : "Avviso legale",
    "Privacy policy" : "Criterio di riservatezza",
    "None/STARTTLS" : "Nessuna/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "Apri la documentazione",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "È importante impostare questo server per poter inviare email, come per il ripristino della password e per le notifiche.",
    "Send mode" : "Modalità di invio",
    "Encryption" : "Cifratura",
    "Sendmail mode" : "Modalità sendmail",
    "From address" : "Indirizzo mittente",
    "Server address" : "Indirizzo del server",
    "Port" : "Porta",
    "Authentication" : "Autenticazione",
    "Authentication required" : "Autenticazione richiesta",
    "Credentials" : "Credenziali",
    "SMTP Password" : "Password SMTP",
    "Save" : "Salva",
    "Test and verify email settings" : "Prova e verifica impostazioni email",
    "Reasons to use Nextcloud in your organization" : "Motivi per utilizzare Nextcloud nella tua organizzazione",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Sviluppato dalla {communityopen}comunità di Nextcloud{linkclose}, il {githubopen}codice sorgente{linkclose} è rilasciato nei termini della licenza {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Mi piace sulla nostra pagina di Facebook!",
    "Follow us on Mastodon" : "Seguici su Mastodon",
    "Check out our blog" : "Leggi il nostro blog!",
    "Subscribe to our newsletter" : "Iscriviti alla nostra newsletter",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Questa versione di Nextcloud della community non è supportata e le notifiche istantanee non sono disponibili.",
    "Use a second factor besides your password to increase security for your account." : "Utilizza un secondo fattore oltre alla tua password per aumentare la sicurezza per il tuo account.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Se utilizzi applicazioni di terze parti per connetterti a Nextcloud, assicurati di creare e configurare una password per ciascuna applicazione prima di abilitare l'autenticazione a due fattori.",
    "Logged in account must be a subadmin" : "L'account che ha eseguito l'accesso deve essere un sotto-amministratore",
    "File locking" : "Blocco dei file",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Il blocco di file transazionale è disattivato, ciò potrebbe comportare problemi di race condition. Attiva \"filelocking.enabled\" nel config.php per evitare questi problemi.",
    "The PHP memory limit is below the recommended value of %s." : "Il limite di memoria di PHP è inferiore al valore consigliato di %s.",
    "Set default expiration date for shares" : "Imposta data di scadenza predefinita per le condivisioni",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Se completamento di \"stesso gruppo\" e \"integrazione numero di telefono\" sono attivi, una corrispondenza in uno dei due è sufficiente per mostrare l'utente.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Consenti il completamento automatico quando inserisci il nome completo o l'indirizzo email (ignorando la corrispondenza della rubrica mancante e l'appartenenza allo stesso gruppo)",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Questa applicazione non contiene l'informazione della versione minima di Nextcloud richiesta. In futuro ciò sarà considerato un errore.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Questa applicazione non contiene l'informazione della versione massima di Nextcloud richiesta. In futuro ciò sarà considerato un errore.",
    "Your biography" : "La tua biografia",
    "You are using <strong>{usage}</strong>" : "Stai utilizzando <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Stai utilizzando <strong>{usage}</strong> di <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In caso di smarrimento di un dispositivo o uscita dall'organizzazione, questa funzione può cancellare a distanza i dati di Nextcloud da tutti i dispositivi associati a {userid}. Funziona solo se i dispositivi sono connessi a Internet.",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Questa applicazione non è marcata come compatibile con la tua versione di Nextcloud. Se continui sarai ancora in grado di installare l'applicazione. Nota che l'applicazione potrebbe non funzionare come previsto.",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "È importante per la sicurezza e le prestazioni della tua istanza che tutto sia configurato correttamente. Per aiutarti in questo senso, stiamo eseguendo alcuni controlli automatici. Vedi la documentazione collegata per ulteriori informazioni.",
    "Checking for system and security issues." : "Verifica di problemi di sistema e sicurezza.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Leggi attentamente le <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">guide d'installazione ↗</a>, e controlla gli errori o gli avvisi nel <a href=\"%2$s\">log</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Controlla la sicurezza del tuo Nextcloud con la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">nostra scansione di sicurezza ↗</a>"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
